==> ledger-accounting-0.0.2.tgz: package/README.md <==

# ledger-accounting

  A simple Javascript double-entry accounting library.

  [![Build Status](https://travis-ci.org/monstercat/ledger-accounting.png)](https://travis-ci.org/monstercat/ledger-accounting)

## Installation

  Install with npm

    $ npm install ledger-accounting

## Example

```js
var ledger = require('ledger-accounting')

var date = new Date();
var account1 = new ledger.Account('foo');
var account2 = new ledger.Account('bar');
var transaction = new ledger.Transaction({date: date});

transaction.transfer(account1, account2, decimal('5'), {note: 'bla'});
```

## License

  The MIT License (MIT)

  Copyright (c) 2014 Caleb Reach

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.

==> ledger-accounting-0.1.2.tgz: package/README.md <==
# ledger-accounting

  A simple Javascript double-entry accounting library.

  [![Build Status](https://travis-ci.org/monstercat/ledger-accounting.png)](https://travis-ci.org/monstercat/ledger-accounting)

## Installation

  Install with npm

    $ npm install ledger-accounting

## Example

```js
var ledger = require('ledger-accounting')
var Account = ledger.Account;
var Transaction = ledger.Transaction;

var date = new Date();
var account1 = Account('foo');
var account2 = Account('bar');
var transaction = Transaction({date: date});

transaction.transfer(account1, account2, decimal('5'), {note: 'bla'});
```

## License

  The MIT License (MIT)

  Copyright (c) 2014 Caleb Reach

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
